#!/usr/bin/python3

'''
    A tool designed to power exploratory data analysis, on airQ collected Air Quality Indicator Data.

    Source : https://github.com/itzmeanjan/airQ-insight
    Companion Repo ( of airQ ) : https://github.com/itzmeanjan/airQ
'''

__version__ = '0.2.5'
__author__ = 'Anjan Roy<anjanroy@yandex.com>'
