#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['airQInsight']

package_data = \
{'': ['*']}

install_requires = \
['matplotlib', 'typing', 'airQ']

extras_require = \
{'dev': ['flit']}

entry_points = \
{'console_scripts': ['airQInsight = airQInsight.app:main']}

setup(name='airQInsight',
      version='0.2.5',
      description='A tool designed to power exploratory data analysis, on airQ collected Air Quality Indicator Data.',
      author='Anjan Roy',
      author_email='anjanroy@yandex.com',
      url='https://github.com/itzmeanjan/airQ-insight/',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.7',
     )
